@@ -1,4 +1,5 @@
 import os, struct, logging
+import numpy as np
 
 if os.name == 'nt':
     afs_home = '\/afs/ipp-garching.mpg.de/home'
@@ -6,6 +7,7 @@ else:
     afs_home = '/afs/ipp-garching.mpg.de/home'
 
 logger = logging.getLogger('aug_sfutils.manage_ed')
+logger.level = logging.INFO
 
 
 def sf_path(nshot, diag, exp='AUGD', ed=0):
@@ -93,9 +95,13 @@ def ed_zero(diag, nshot, exp='augd'):
     ed_d = read_ed_cntl(fed_dir, exp=exp)
     if ed_d is None:
         return None
-    logger.debug(nshot, ed_d)
+    logger.debug(nshot)
     if nshot in ed_d.keys():
-        return ed_d[nshot]
+        if ed_d[nshot] == -1:
+            logger.error('Edition control found ed=-1')
+            return None
+        else:
+            return ed_d[nshot]
     else:
         return None
 
@@ -134,11 +140,14 @@ def read_ed_cntl(fed_dir, exp='augd'):
             jbyt += delta_byt
             sshot = b''.join(shot)
             nshot = int(sshot)
-            max_ed[nshot] = ed
+            max_ed[nshot] = np.int32(ed)
         except:
             break
 
-    return max_ed
+    if len(max_ed.keys()) > 0:
+        return max_ed
+    else:
+        return None
 
 
 if __name__ == '__main__':
