@@ -2,15 +2,17 @@
 Equilibrium utilities library
 """
 
-import sys, time, logging
+import sys, time, logging, datetime
 import numpy as np
 from scipy.ndimage.interpolation import map_coordinates
 from scipy.interpolate import UnivariateSpline, interp1d, InterpolatedUnivariateSpline, RectBivariateSpline
 
-
 logger = logging.getLogger('aug_sfutils.mapeq')
 #logger.setLevel(logging.INFO)
 
+def compare_version(a, b):
+    from pkg_resources import parse_version
+    return parse_version(a) >= parse_version(b)
 
 def get_nearest_index(tim_eq, tarr):
     """Find nearest time index for a given time.
@@ -265,7 +267,7 @@ def rz2brzt(eqm, r_in, z_in, t_in=None):
 
     return interpBr/(-abs(eqm.psi_fac)*dz), \
            interpBz/(-abs(eqm.psi_fac)*dr), \
-           interpBt/eqm.psi_fac * eqm.phi_sign
+           interpBt/(2.*np.pi) * eqm.psi_sign * eqm.phi_sign
 
 
 def Bmesh(eqm, t_in=None):
@@ -319,7 +321,7 @@ def Bmesh(eqm, t_in=None):
 
     return Br/(-abs(eqm.psi_fac)*dz), \
            Bz/(-abs(eqm.psi_fac)*dr), \
-           Bt/eqm.psi_fac * eqm.phi_sign
+           Bt/(2.*np.pi) * eqm.psi_sign * eqm.phi_sign
 
 
 def rz2rho(eqm, r_in, z_in, t_in=None, coord_out='rho_pol', extrapolate=True):
@@ -432,6 +434,7 @@ def rho2rz(eqm, rho_in, t_in=None, coord_in='rho_pol', all_lines=False):
              coord_in=coord_in, coord_out='Psi', extrapolate=True )
 
     from matplotlib import _contour
+    import matplotlib
 
     nt = len(tarr)
     nr = len(eqm.Rmesh)
@@ -459,7 +462,7 @@ def rho2rz(eqm, rho_in, t_in=None, coord_in='rho_pol', all_lines=False):
 
         for jfl, fl in enumerate(Flux):
             verts = cgen.create_contour(fl)
-            if compare_version(matplotlib.__version__, '3.4.3') >= 0:
+            if compare_version(matplotlib.__version__, '3.4.3'):
                 """After MPL ver 3.4.3 the return type is vertices and codes as a list. Prior it was just vertices"""
                 segs = verts[0]
             else:
@@ -849,7 +852,12 @@ def to_geqdsk(equ, t_in=0., cocos_out=1):
 
     geq = {}
 
+    today = datetime.datetime.today()
+    date = today.strftime("%d%b%Y")
+
     geq['CASE'] = np.array(['  CLISTE ', '    ', '   ', ' #' + str(equ.shot), '  %.2fs' % t_in, '  ' + 'EQI'], dtype='<U8')
+
+    geq['CASE2'] = 'CLISTE %s  %s   %d    t~%10.5f     ' %(date, equ.diag, equ.shot, t_in)
     
     # separatrix R and Z
     geq['RBBBS'], geq['ZBBBS'] = rho2rz(equ, 0.999, t_in=equ.time[jt], all_lines=False)
