@@ -113,9 +113,9 @@ class EQU:
 
         jcoco = self.cocos%10 - 1
         ebp   = self.cocos//10
-        psi_sign = -self.ip_ccw*sigma['bp'][jcoco]*sigma['rphiz'][jcoco]
+        self.psi_sign = -self.ip_ccw*sigma['bp'][jcoco]*sigma['rphiz'][jcoco]
         psi_2pi  = (2.*np.pi)**ebp
-        self.psi_fac = psi_sign*psi_2pi
+        self.psi_fac = self.psi_sign*psi_2pi
         self.phi_sign = self.bt_ccw*sigma['rphiz'][jcoco]
 
         if 'tbeg' in kwargs.keys():
@@ -158,7 +158,7 @@ class EQU:
 
         grad_area = np.apply_along_axis(np.gradient, -1, self.area)
 
-        if self.ffp is not None:
+        if self.ffp is not None and self.rinv is not None:
             self.jav = 2.*np.pi*self.dpres/self.rinv + self.ffp*self.rinv/2e-7
             curr_prof = np.cumsum(self.jav*grad_area, axis=-1)
         ## Plasma current [A] as integral of current density
