@@ -6,7 +6,7 @@ from aug_sfutils import sfdics, str_byt
 n_rel = 8
 
 logger = logging.getLogger('aug_sfutils.sfhread')
-#logger.setLevel(logging.INFO)
+logger.setLevel(logging.INFO)
 #logger.setLevel(logging.DEBUG)
 
 
@@ -25,6 +25,8 @@ def read_sfh(byt_str):
     n_obj = n_max
     for j in range(n_max):
         sfo = SFH_READ(byt_str[j*128: (j+1)*128])
+        if not hasattr(sfo, 'obj_type'):
+            continue
         sfo.objid = j
         onam = str_byt.to_str(sfo.objnam.strip())
         if sfo.obj_type == Diagnostic:
@@ -50,7 +52,12 @@ class SFH_READ:
         """
         Reads the SFH part of an object, common to all objects
         """
-        self.objnam   = str_byt.to_str(byte_str[0:8].strip())
+        self.objnam = str_byt.to_str(byte_str[0:8])
+
+        if not self.objnam:
+            logger.error('Error: empty object name')
+            return
+
         self.obj_type, self.level, self.status = unpack('>3H', byte_str[ 8: 14])
         typ = self.obj_type
         if typ in sfdics.obj_name.keys():
@@ -62,7 +69,9 @@ class SFH_READ:
         self.rel      = list(unpack(fmt,  byte_str[16        : 16+2*n_rel]))
         self.address, self.length = unpack('>2I', byte_str[16+2*n_rel: 24+2*n_rel])
         self.val      = byte_str[40:  64]
+        logger.debug(self.objnam)
         self.descr    = str_byt.to_str(byte_str[64: 128].strip())
+        logger.debug(self.descr)
 
         val_func = { \
             1 : self.sfdiag, 2: self.list, 3: self.device, 4: self.parmset, \
@@ -75,7 +84,7 @@ class SFH_READ:
         if typ in val_func.keys():
             val_func[typ]()
         else:
-            logger.error('Object type %d not supported', sfo.obj_type)
+            logger.error('Object type %d of object %s not supported', self.obj_type, self.objnam)
 
 
     def sfdiag(self):
