@@ -18,7 +18,8 @@ def to_str(str_or_byt, strip=True):
 
     if sys.version_info >= (3, 0, 0):
         if isinstance(str_or_byt, bytes):
-            str_out = str_or_byt.decode('utf8')
+#            str_out = str_or_byt.decode('utf8')
+            str_out = str_or_byt.decode('iso-8859-1').replace('\x00', '')
         else:
             str_out = str_or_byt
     else:
