@@ -6,8 +6,8 @@ import numpy as np
 from aug_sfutils import sfdics, str_byt
 
 logger = logging.getLogger('aug_sfutils.ww')
-logger.setLevel(logging.INFO)
-logger.setLevel(logging.DEBUG)
+#logger.setLevel(logging.INFO)
+#logger.setLevel(logging.DEBUG)
 
 
 wwlib = '/afs/ipp-garching.mpg.de/aug/ads/lib64/@sys/libddww8.so.8.1'
